@@ -38,8 +38,8 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
            '-Wp,-D__USE_MINGW_ANSI_STDIO=1 -O3',
  'CFLAGSFORSHARED': '',
  'CFLAGS_ALIASING': '-fno-strict-aliasing',
- 'CODECS_COMMON_HEADERS': '../Python-3.12.8/Modules/cjkcodecs/multibytecodec.h '
-                          '../Python-3.12.8/Modules/cjkcodecs/cjkcodecs.h',
+ 'CODECS_COMMON_HEADERS': '../Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                          '../Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
@@ -55,7 +55,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                             '-fvisibility=hidden -D_WIN32_WINNT=0x0602 '
                             '-DPY3_DLLNAME=\'L"libpython3.12.dll"\' '
                             '-DMS_DLL_ID=\'"3.12-arm64"\'',
- 'CONFIGURE_CPPFLAGS': '-I../Python-3.12.8/PC  -I.',
+ 'CONFIGURE_CPPFLAGS': '-I../Python-3.12.9/PC  -I.',
  'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '-flto=thin -g',
  'CONFIGURE_LDFLAGS_NOLTO': '-flto=thin',
@@ -81,13 +81,13 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
- 'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Python-3.12.8/Include '
-             '-I../Python-3.12.8/PC  -I.',
+ 'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Python-3.12.9/Include '
+             '-I../Python-3.12.9/PC  -I.',
  'CXX': 'clang++',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
- 'DEEPFREEZE_DEPS': '../Python-3.12.8/Tools/build/deepfreeze.py '
+ 'DEEPFREEZE_DEPS': '../Python-3.12.9/Tools/build/deepfreeze.py '
                     '_bootstrap_python '
-                    '../Python-3.12.8/Programs/_freeze_module.py \\',
+                    '../Python-3.12.9/Programs/_freeze_module.py \\',
  'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
  'DESTDIRS': '/clangarm64 /clangarm64/lib /clangarm64/lib/python3.12 '
              '/clangarm64/lib/python3.12/lib-dynload',
@@ -125,11 +125,11 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'EXT_SUFFIX': '.cp312-mingw_aarch64_ucrt_llvm.pyd',
  'FILEMODE': 644,
  'FREEZE_MODULE': './_bootstrap_python '
-                  '../Python-3.12.8/Programs/_freeze_module.py',
+                  '../Python-3.12.9/Programs/_freeze_module.py',
  'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
  'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
  'FREEZE_MODULE_DEPS': '_bootstrap_python '
-                       '../Python-3.12.8/Programs/_freeze_module.py',
+                       '../Python-3.12.9/Programs/_freeze_module.py',
  'FROZEN_FILES_IN': '\\',
  'FROZEN_FILES_OUT': '\\',
  'GETPGRP_HAVE_ARG': 0,
@@ -558,6 +558,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'HAVE_SYS_MODEM_H': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
+ 'HAVE_SYS_PIDFD_H': 0,
  'HAVE_SYS_POLL_H': 0,
  'HAVE_SYS_RANDOM_H': 0,
  'HAVE_SYS_RESOURCE_H': 0,
@@ -592,7 +593,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'HAVE_TMPNAM_R': 0,
  'HAVE_TM_ZONE': 0,
  'HAVE_TRUNCATE': 0,
- 'HAVE_TTYNAME': 0,
+ 'HAVE_TTYNAME_R': 0,
  'HAVE_TZNAME': 1,
  'HAVE_UMASK': 1,
  'HAVE_UNAME': 0,
@@ -665,12 +666,12 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                     '-DPY3_DLLNAME=\'L"libpython3.12.dll"\' '
                     '-DMS_DLL_ID=\'"3.12-arm64"\' '
                     '-fprofile-instr-use=C:/M/B/src/build-CLANGARM64/code.profclangd '
-                    '-I../Python-3.12.8/Include/internal -IObjects -IInclude '
-                    '-IPython -I. -I../Python-3.12.8/Include '
-                    '-I../Python-3.12.8/PC  -I.',
+                    '-I../Python-3.12.9/Include/internal -IObjects -IInclude '
+                    '-IPython -I. -I../Python-3.12.9/Include '
+                    '-I../Python-3.12.9/PC  -I.',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
- 'LIBHACL_CFLAGS': '-I../Python-3.12.8/Modules/_hacl/include -D_BSD_SOURCE '
+ 'LIBHACL_CFLAGS': '-I../Python-3.12.9/Modules/_hacl/include -D_BSD_SOURCE '
                    '-D_DEFAULT_SOURCE -fno-strict-overflow -Wsign-compare '
                    '-Wunreachable-code -DNDEBUG -g -O3 -Wall -O2 -pipe '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
@@ -684,9 +685,9 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                    '-DPY3_DLLNAME=\'L"libpython3.12.dll"\' '
                    '-DMS_DLL_ID=\'"3.12-arm64"\' '
                    '-fprofile-instr-use=C:/M/B/src/build-CLANGARM64/code.profclangd '
-                   '-I../Python-3.12.8/Include/internal -IObjects -IInclude '
-                   '-IPython -I. -I../Python-3.12.8/Include '
-                   '-I../Python-3.12.8/PC  -I.',
+                   '-I../Python-3.12.9/Include/internal -IObjects -IInclude '
+                   '-IPython -I. -I../Python-3.12.9/Include '
+                   '-I../Python-3.12.9/PC  -I.',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
@@ -707,9 +708,9 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                     '-DPY3_DLLNAME=\'L"libpython3.12.dll"\' '
                     '-DMS_DLL_ID=\'"3.12-arm64"\' '
                     '-fprofile-instr-use=C:/M/B/src/build-CLANGARM64/code.profclangd '
-                    '-I../Python-3.12.8/Include/internal -IObjects -IInclude '
-                    '-IPython -I. -I../Python-3.12.8/Include '
-                    '-I../Python-3.12.8/PC  -I.',
+                    '-I../Python-3.12.9/Include/internal -IObjects -IInclude '
+                    '-IPython -I. -I../Python-3.12.9/Include '
+                    '-I../Python-3.12.9/PC  -I.',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -741,7 +742,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '../Python-3.12.8/Modules/makesetup',
+ 'MAKESETUP': '../Python-3.12.9/Modules/makesetup',
  'MANDIR': '/clangarm64/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'array  _asyncio  _bisect  _contextvars  _csv  _heapq  '
@@ -798,7 +799,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE_BINASCII_CFLAGS': '-DUSE_ZLIB_CRC32',
  'MODULE_BINASCII_LDFLAGS': '-lz',
  'MODULE_BINASCII_STATE': 'yes',
- 'MODULE_CMATH_DEPS': '../Python-3.12.8/Modules/_math.h',
+ 'MODULE_CMATH_DEPS': '../Python-3.12.9/Modules/_math.h',
  'MODULE_CMATH_LDFLAGS': '-lm',
  'MODULE_CMATH_STATE': 'yes',
  'MODULE_DEPS_SHARED': 'Modules/config.c',
@@ -808,7 +809,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE_FCNTL_STATE': 'missing',
  'MODULE_GRP_STATE': 'missing',
  'MODULE_ITERTOOLS_LDFLAGS': '',
- 'MODULE_MATH_DEPS': '../Python-3.12.8/Modules/_math.h',
+ 'MODULE_MATH_DEPS': '../Python-3.12.9/Modules/_math.h',
  'MODULE_MATH_LDFLAGS': '-lm',
  'MODULE_MATH_STATE': 'yes',
  'MODULE_MMAP_STATE': 'yes',
@@ -831,8 +832,8 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE_TERMIOS_STATE': 'missing',
  'MODULE_TIME_LDFLAGS': '',
  'MODULE_TIME_STATE': 'yes',
- 'MODULE_UNICODEDATA_DEPS': '../Python-3.12.8/Modules/unicodedata_db.h '
-                            '../Python-3.12.8/Modules/unicodename_db.h',
+ 'MODULE_UNICODEDATA_DEPS': '../Python-3.12.9/Modules/unicodedata_db.h '
+                            '../Python-3.12.9/Modules/unicodename_db.h',
  'MODULE_UNICODEDATA_STATE': 'yes',
  'MODULE_WINREG_LDFLAGS': '',
  'MODULE_WINSOUND_LDFLAGS': '-lwinmm',
@@ -847,63 +848,63 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE__ASYNCIO_STATE': 'yes',
  'MODULE__BISECT_STATE': 'yes',
  'MODULE__BLAKE2_CFLAGS': '',
- 'MODULE__BLAKE2_DEPS': '../Python-3.12.8/Modules/_blake2/impl/blake2-config.h '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2-impl.h '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2.h '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2b-load-sse2.h '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2b-load-sse41.h '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2b-ref.c '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2b-round.h '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2b.c '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2s-load-sse2.h '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2s-load-sse41.h '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2s-load-xop.h '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2s-ref.c '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2s-round.h '
-                        '../Python-3.12.8/Modules/_blake2/impl/blake2s.c '
-                        '../Python-3.12.8/Modules/_blake2/blake2module.h '
-                        '../Python-3.12.8/Modules/hashlib.h',
+ 'MODULE__BLAKE2_DEPS': '../Python-3.12.9/Modules/_blake2/impl/blake2-config.h '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2-impl.h '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2.h '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2b-load-sse2.h '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2b-load-sse41.h '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2b-ref.c '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2b-round.h '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2b.c '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2s-load-sse2.h '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2s-load-sse41.h '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2s-load-xop.h '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2s-ref.c '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2s-round.h '
+                        '../Python-3.12.9/Modules/_blake2/impl/blake2s.c '
+                        '../Python-3.12.9/Modules/_blake2/blake2module.h '
+                        '../Python-3.12.9/Modules/hashlib.h',
  'MODULE__BLAKE2_LDFLAGS': '',
  'MODULE__BLAKE2_STATE': 'yes',
  'MODULE__BZ2_CFLAGS': '',
  'MODULE__BZ2_LDFLAGS': '-lbz2',
  'MODULE__BZ2_STATE': 'yes',
- 'MODULE__CODECS_CN_DEPS': '../Python-3.12.8/Modules/cjkcodecs/mappings_cn.h '
-                           '../Python-3.12.8/Modules/cjkcodecs/multibytecodec.h '
-                           '../Python-3.12.8/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_CN_DEPS': '../Python-3.12.9/Modules/cjkcodecs/mappings_cn.h '
+                           '../Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                           '../Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_CN_STATE': 'yes',
- 'MODULE__CODECS_HK_DEPS': '../Python-3.12.8/Modules/cjkcodecs/mappings_hk.h  '
-                           '../Python-3.12.8/Modules/cjkcodecs/multibytecodec.h '
-                           '../Python-3.12.8/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_HK_DEPS': '../Python-3.12.9/Modules/cjkcodecs/mappings_hk.h  '
+                           '../Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                           '../Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_HK_STATE': 'yes',
- 'MODULE__CODECS_ISO2022_DEPS': '../Python-3.12.8/Modules/cjkcodecs/mappings_jisx0213_pair.h '
-                                '../Python-3.12.8/Modules/cjkcodecs/alg_jisx0201.h '
-                                '../Python-3.12.8/Modules/cjkcodecs/emu_jisx0213_2000.h '
-                                '../Python-3.12.8/Modules/cjkcodecs/multibytecodec.h '
-                                '../Python-3.12.8/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_ISO2022_DEPS': '../Python-3.12.9/Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                                '../Python-3.12.9/Modules/cjkcodecs/alg_jisx0201.h '
+                                '../Python-3.12.9/Modules/cjkcodecs/emu_jisx0213_2000.h '
+                                '../Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                                '../Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_ISO2022_STATE': 'yes',
- 'MODULE__CODECS_JP_DEPS': '../Python-3.12.8/Modules/cjkcodecs/mappings_jisx0213_pair.h '
-                           '../Python-3.12.8/Modules/cjkcodecs/alg_jisx0201.h '
-                           '../Python-3.12.8/Modules/cjkcodecs/emu_jisx0213_2000.h '
-                           '../Python-3.12.8/Modules/cjkcodecs/mappings_jp.h '
-                           '../Python-3.12.8/Modules/cjkcodecs/multibytecodec.h '
-                           '../Python-3.12.8/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_JP_DEPS': '../Python-3.12.9/Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                           '../Python-3.12.9/Modules/cjkcodecs/alg_jisx0201.h '
+                           '../Python-3.12.9/Modules/cjkcodecs/emu_jisx0213_2000.h '
+                           '../Python-3.12.9/Modules/cjkcodecs/mappings_jp.h '
+                           '../Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                           '../Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_JP_STATE': 'yes',
- 'MODULE__CODECS_KR_DEPS': '../Python-3.12.8/Modules/cjkcodecs/mappings_kr.h '
-                           '../Python-3.12.8/Modules/cjkcodecs/multibytecodec.h '
-                           '../Python-3.12.8/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_KR_DEPS': '../Python-3.12.9/Modules/cjkcodecs/mappings_kr.h '
+                           '../Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                           '../Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_KR_STATE': 'yes',
  'MODULE__CODECS_LDFLAGS': '',
- 'MODULE__CODECS_TW_DEPS': '../Python-3.12.8/Modules/cjkcodecs/mappings_tw.h '
-                           '../Python-3.12.8/Modules/cjkcodecs/multibytecodec.h '
-                           '../Python-3.12.8/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_TW_DEPS': '../Python-3.12.9/Modules/cjkcodecs/mappings_tw.h '
+                           '../Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                           '../Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_TW_STATE': 'yes',
  'MODULE__COLLECTIONS_LDFLAGS': '',
  'MODULE__CONTEXTVARS_STATE': 'yes',
  'MODULE__CRYPT_STATE': 'missing',
  'MODULE__CSV_STATE': 'yes',
  'MODULE__CTYPES_CFLAGS': '-fno-strict-overflow',
- 'MODULE__CTYPES_DEPS': '../Python-3.12.8/Modules/_ctypes/ctypes.h',
+ 'MODULE__CTYPES_DEPS': '../Python-3.12.9/Modules/_ctypes/ctypes.h',
  'MODULE__CTYPES_LDFLAGS': '-lffi -lole32 -loleaut32 -luuid',
  'MODULE__CTYPES_MALLOC_CLOSURE': '',
  'MODULE__CTYPES_STATE': 'yes',
@@ -918,21 +919,21 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE__DATETIME_STATE': 'yes',
  'MODULE__DBM_STATE': 'missing',
  'MODULE__DECIMAL_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1',
- 'MODULE__DECIMAL_DEPS': '../Python-3.12.8/Modules/_decimal/docstrings.h',
+ 'MODULE__DECIMAL_DEPS': '../Python-3.12.9/Modules/_decimal/docstrings.h',
  'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
  'MODULE__DECIMAL_STATE': 'yes',
  'MODULE__ELEMENTTREE_CFLAGS': '',
- 'MODULE__ELEMENTTREE_DEPS': '../Python-3.12.8/Modules/pyexpat.c',
+ 'MODULE__ELEMENTTREE_DEPS': '../Python-3.12.9/Modules/pyexpat.c',
  'MODULE__ELEMENTTREE_STATE': 'yes',
  'MODULE__FUNCTOOLS_LDFLAGS': '',
  'MODULE__GDBM_STATE': 'missing',
  'MODULE__HASHLIB_CFLAGS': '',
- 'MODULE__HASHLIB_DEPS': '../Python-3.12.8/Modules/hashlib.h',
+ 'MODULE__HASHLIB_DEPS': '../Python-3.12.9/Modules/hashlib.h',
  'MODULE__HASHLIB_LDFLAGS': '-lcrypto',
  'MODULE__HASHLIB_STATE': 'yes',
  'MODULE__HEAPQ_STATE': 'yes',
- 'MODULE__IO_CFLAGS': '-I../Python-3.12.8/Modules/_io',
- 'MODULE__IO_DEPS': '../Python-3.12.8/Modules/_io/_iomodule.h',
+ 'MODULE__IO_CFLAGS': '-I../Python-3.12.9/Modules/_io',
+ 'MODULE__IO_DEPS': '../Python-3.12.9/Modules/_io/_iomodule.h',
  'MODULE__IO_LDFLAGS': '',
  'MODULE__IO_STATE': 'yes',
  'MODULE__JSON_STATE': 'yes',
@@ -941,18 +942,18 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE__LZMA_CFLAGS': '',
  'MODULE__LZMA_LDFLAGS': '-llzma',
  'MODULE__LZMA_STATE': 'yes',
- 'MODULE__MD5_CFLAGS': '-I../Python-3.12.8/Modules/_hacl/include '
-                       '-I../Python-3.12.8/Modules/_hacl/internal '
+ 'MODULE__MD5_CFLAGS': '-I../Python-3.12.9/Modules/_hacl/include '
+                       '-I../Python-3.12.9/Modules/_hacl/internal '
                        '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
- 'MODULE__MD5_DEPS': '../Python-3.12.8/Modules/hashlib.h \\ '
+ 'MODULE__MD5_DEPS': '../Python-3.12.9/Modules/hashlib.h \\ '
                      'Modules/_hacl/Hacl_Hash_MD5.h '
                      'Modules/_hacl/Hacl_Hash_MD5.c',
  'MODULE__MD5_STATE': 'yes',
  'MODULE__MSI_LDFLAGS': '-lmsi -lcabinet -lrpcrt4',
  'MODULE__MSI_STATE': 'yes',
- 'MODULE__MULTIBYTECODEC_DEPS': '../Python-3.12.8/Modules/cjkcodecs/multibytecodec.h',
+ 'MODULE__MULTIBYTECODEC_DEPS': '../Python-3.12.9/Modules/cjkcodecs/multibytecodec.h',
  'MODULE__MULTIBYTECODEC_STATE': 'yes',
- 'MODULE__MULTIPROCESSING_CFLAGS': '-I../Python-3.12.8/Modules/_multiprocessing',
+ 'MODULE__MULTIPROCESSING_CFLAGS': '-I../Python-3.12.9/Modules/_multiprocessing',
  'MODULE__MULTIPROCESSING_LDFLAGS': '-lws2_32',
  'MODULE__MULTIPROCESSING_STATE': 'yes',
  'MODULE__OPCODE_STATE': 'yes',
@@ -965,49 +966,49 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE__QUEUE_STATE': 'yes',
  'MODULE__RANDOM_STATE': 'yes',
  'MODULE__SCPROXY_STATE': 'disabled',
- 'MODULE__SHA1_CFLAGS': '-I../Python-3.12.8/Modules/_hacl/include '
-                        '-I../Python-3.12.8/Modules/_hacl/internal '
+ 'MODULE__SHA1_CFLAGS': '-I../Python-3.12.9/Modules/_hacl/include '
+                        '-I../Python-3.12.9/Modules/_hacl/internal '
                         '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
- 'MODULE__SHA1_DEPS': '../Python-3.12.8/Modules/hashlib.h \\ '
+ 'MODULE__SHA1_DEPS': '../Python-3.12.9/Modules/hashlib.h \\ '
                       'Modules/_hacl/Hacl_Hash_SHA1.h '
                       'Modules/_hacl/Hacl_Hash_SHA1.c',
  'MODULE__SHA1_STATE': 'yes',
- 'MODULE__SHA2_CFLAGS': '-I../Python-3.12.8/Modules/_hacl/include '
-                        '-I../Python-3.12.8/Modules/_hacl/internal '
+ 'MODULE__SHA2_CFLAGS': '-I../Python-3.12.9/Modules/_hacl/include '
+                        '-I../Python-3.12.9/Modules/_hacl/internal '
                         '-D_BSD_SOURCE -D_DEFAULT_SOURCE',
- 'MODULE__SHA2_DEPS': '../Python-3.12.8/Modules/hashlib.h \\ '
+ 'MODULE__SHA2_DEPS': '../Python-3.12.9/Modules/hashlib.h \\ '
                       'Modules/_hacl/libHacl_Hash_SHA2.a',
  'MODULE__SHA2_STATE': 'yes',
- 'MODULE__SHA3_DEPS': '../Python-3.12.8/Modules/hashlib.h \\ '
+ 'MODULE__SHA3_DEPS': '../Python-3.12.9/Modules/hashlib.h \\ '
                       'Modules/_hacl/Hacl_Hash_SHA3.h '
                       'Modules/_hacl/Hacl_Hash_SHA3.c',
  'MODULE__SHA3_STATE': 'yes',
- 'MODULE__SOCKET_DEPS': '../Python-3.12.8/Modules/socketmodule.h '
-                        '../Python-3.12.8/Modules/addrinfo.h '
-                        '../Python-3.12.8/Modules/getaddrinfo.c '
-                        '../Python-3.12.8/Modules/getnameinfo.c',
+ 'MODULE__SOCKET_DEPS': '../Python-3.12.9/Modules/socketmodule.h '
+                        '../Python-3.12.9/Modules/addrinfo.h '
+                        '../Python-3.12.9/Modules/getaddrinfo.c '
+                        '../Python-3.12.9/Modules/getnameinfo.c',
  'MODULE__SOCKET_LDFLAGS': '-lws2_32 -liphlpapi -lrpcrt4',
  'MODULE__SOCKET_STATE': 'yes',
- 'MODULE__SQLITE3_CFLAGS': '-I../Python-3.12.8/Modules/_sqlite',
- 'MODULE__SQLITE3_DEPS': '../Python-3.12.8/Modules/_sqlite/connection.h '
-                         '../Python-3.12.8/Modules/_sqlite/cursor.h '
-                         '../Python-3.12.8/Modules/_sqlite/microprotocols.h '
-                         '../Python-3.12.8/Modules/_sqlite/module.h '
-                         '../Python-3.12.8/Modules/_sqlite/prepare_protocol.h '
-                         '../Python-3.12.8/Modules/_sqlite/row.h '
-                         '../Python-3.12.8/Modules/_sqlite/util.h',
+ 'MODULE__SQLITE3_CFLAGS': '-I../Python-3.12.9/Modules/_sqlite',
+ 'MODULE__SQLITE3_DEPS': '../Python-3.12.9/Modules/_sqlite/connection.h '
+                         '../Python-3.12.9/Modules/_sqlite/cursor.h '
+                         '../Python-3.12.9/Modules/_sqlite/microprotocols.h '
+                         '../Python-3.12.9/Modules/_sqlite/module.h '
+                         '../Python-3.12.9/Modules/_sqlite/prepare_protocol.h '
+                         '../Python-3.12.9/Modules/_sqlite/row.h '
+                         '../Python-3.12.9/Modules/_sqlite/util.h',
  'MODULE__SQLITE3_LDFLAGS': '-lsqlite3',
  'MODULE__SQLITE3_STATE': 'yes',
  'MODULE__SRE_LDFLAGS': '',
  'MODULE__SSL_CFLAGS': '',
- 'MODULE__SSL_DEPS': '../Python-3.12.8/Modules/_ssl.h '
-                     '../Python-3.12.8/Modules/_ssl/cert.c '
-                     '../Python-3.12.8/Modules/_ssl/debughelpers.c '
-                     '../Python-3.12.8/Modules/_ssl/misc.c '
-                     '../Python-3.12.8/Modules/_ssl_data.h '
-                     '../Python-3.12.8/Modules/_ssl_data_111.h '
-                     '../Python-3.12.8/Modules/_ssl_data_300.h '
-                     '../Python-3.12.8/Modules/socketmodule.h',
+ 'MODULE__SSL_DEPS': '../Python-3.12.9/Modules/_ssl.h '
+                     '../Python-3.12.9/Modules/_ssl/cert.c '
+                     '../Python-3.12.9/Modules/_ssl/debughelpers.c '
+                     '../Python-3.12.9/Modules/_ssl/misc.c '
+                     '../Python-3.12.9/Modules/_ssl_data.h '
+                     '../Python-3.12.9/Modules/_ssl_data_111.h '
+                     '../Python-3.12.9/Modules/_ssl_data_300.h '
+                     '../Python-3.12.9/Modules/socketmodule.h',
  'MODULE__SSL_LDFLAGS': '-lssl -lcrypto -lws2_32',
  'MODULE__SSL_STATE': 'yes',
  'MODULE__STATISTICS_LDFLAGS': '-lm',
@@ -1016,9 +1017,9 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'MODULE__STRUCT_STATE': 'yes',
  'MODULE__SYMTABLE_LDFLAGS': '',
  'MODULE__TESTBUFFER_STATE': 'yes',
- 'MODULE__TESTCAPI_DEPS': '../Python-3.12.8/Modules/_testcapi/testcapi_long.h '
-                          '../Python-3.12.8/Modules/_testcapi/parts.h '
-                          '../Python-3.12.8/Modules/_testcapi/util.h',
+ 'MODULE__TESTCAPI_DEPS': '../Python-3.12.9/Modules/_testcapi/testcapi_long.h '
+                          '../Python-3.12.9/Modules/_testcapi/parts.h '
+                          '../Python-3.12.9/Modules/_testcapi/util.h',
  'MODULE__TESTCAPI_STATE': 'yes',
  'MODULE__TESTCLINIC_STATE': 'yes',
  'MODULE__TESTCONSOLE_STATE': 'yes',
@@ -1102,10 +1103,10 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                              '-DPY3_DLLNAME=\'L"libpython3.12.dll"\' '
                              '-DMS_DLL_ID=\'"3.12-arm64"\' '
                              '-fprofile-instr-use=C:/M/B/src/build-CLANGARM64/code.profclangd '
-                             '-I../Python-3.12.8/Include/internal -IObjects '
+                             '-I../Python-3.12.9/Include/internal -IObjects '
                              '-IInclude -IPython -I. '
-                             '-I../Python-3.12.8/Include '
-                             '-I../Python-3.12.8/PC  -I. '
+                             '-I../Python-3.12.9/Include '
+                             '-I../Python-3.12.9/PC  -I. '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -Wunreachable-code -DNDEBUG '
               '-g -O3 -Wall -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 '
@@ -1121,7 +1122,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                      '-DPY3_DLLNAME=\'L"libpython3.12.dll"\' '
                      '-DMS_DLL_ID=\'"3.12-arm64"\' '
                      '-fprofile-instr-use=C:/M/B/src/build-CLANGARM64/code.profclangd '
-                     '-I../Python-3.12.8/Include/internal',
+                     '-I../Python-3.12.9/Include/internal',
  'PY_COERCE_C_LOCALE': 0,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -Wunreachable-code '
                    '-DNDEBUG -g -O3 -Wall -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 '
@@ -1136,12 +1137,12 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                    '-DPY3_DLLNAME=\'L"libpython3.12.dll"\' '
                    '-DMS_DLL_ID=\'"3.12-arm64"\' '
                    '-fprofile-instr-use=C:/M/B/src/build-CLANGARM64/code.profclangd '
-                   '-I../Python-3.12.8/Include/internal -IObjects -IInclude '
-                   '-IPython -I. -I../Python-3.12.8/Include '
-                   '-I../Python-3.12.8/PC  -I. -DPy_BUILD_CORE',
+                   '-I../Python-3.12.9/Include/internal -IObjects -IInclude '
+                   '-IPython -I. -I../Python-3.12.9/Include '
+                   '-I../Python-3.12.9/PC  -I. -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-flto=thin -g',
- 'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Python-3.12.8/Include '
-                '-I../Python-3.12.8/PC  -I.',
+ 'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Python-3.12.9/Include '
+                '-I../Python-3.12.9/PC  -I.',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 0,
  'PY_LDFLAGS': '',
@@ -1165,9 +1166,9 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
                         '-DPY3_DLLNAME=\'L"libpython3.12.dll"\' '
                         '-DMS_DLL_ID=\'"3.12-arm64"\' '
                         '-fprofile-instr-use=C:/M/B/src/build-CLANGARM64/code.profclangd '
-                        '-I../Python-3.12.8/Include/internal -IObjects '
-                        '-IInclude -IPython -I. -I../Python-3.12.8/Include '
-                        '-I../Python-3.12.8/PC  -I.',
+                        '-I../Python-3.12.9/Include/internal -IObjects '
+                        '-IInclude -IPython -I. -I../Python-3.12.9/Include '
+                        '-I../Python-3.12.9/PC  -I.',
  'PY_SUPPORT_TIER': 0,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
@@ -1176,7 +1177,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'Py_SUNOS_VERSION': 0,
  'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
- 'RCFLAGS': '-DFIELD3=8150 -O COFF',
+ 'RCFLAGS': '-DFIELD3=9150 -O COFF',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
@@ -1284,7 +1285,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
             'Modules/_testcapi   Modules/_xxtestfuzz   Modules/cjkcodecs   '
             'Modules/expat   Objects   Parser   Programs   Python   '
             'Python/frozen_modules   Python/deepfreeze PC',
- 'SRC_GDB_HOOKS': '../Python-3.12.8/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '../Python-3.12.9/Tools/gdb/libpython.py',
  'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -1297,7 +1298,7 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'TESTPATH': '',
  'TESTPYTHON': './python.exe -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': './python.exe -E ../Python-3.12.8/Tools/scripts/run_tests.py',
+ 'TESTRUNNER': './python.exe -E ../Python-3.12.9/Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
@@ -1307,11 +1308,11 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'TZPATH': '/clangarm64/share/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': '../Python-3.12.8/Tools/build/update_file.py',
+ 'UPDATE_FILE': '../Python-3.12.9/Tools/build/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'VENVLAUNCHERDIR': '/clangarm64/lib/python3.12/venv/scripts/nt',
  'VERSION': '3.12',
- 'VPATH': '../Python-3.12.8',
+ 'VPATH': '../Python-3.12.9',
  'WASM_ASSETS_DIR': './clangarm64',
  'WASM_STDLIB': './clangarm64/lib/python3.12/os.py',
  'WHEEL_PKG_DIR': '',
@@ -1331,14 +1332,14 @@ build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
  'abs_builddir': 'C:/M/B/src/build-CLANGARM64',
  'abs_builddir_b2h': 'C:/M/B/src/build-CLANGARM64',
- 'abs_srcdir': 'C:/M/B/src/Python-3.12.8',
- 'abs_srcdir_b2h': 'C:/M/B/src/Python-3.12.8',
+ 'abs_srcdir': 'C:/M/B/src/Python-3.12.9',
+ 'abs_srcdir_b2h': 'C:/M/B/src/Python-3.12.9',
  'datarootdir': '/clangarm64/share',
  'exec_prefix': '/clangarm64',
  'prefix': 'C:/msys64/clangarm64',
  'prefix_b2h': 'C:/msys64/clangarm64',
- 'srcdir': 'C:/M/B/src/Python-3.12.8',
- 'srcdir_b2h': 'C:/M/B/src/Python-3.12.8'}
+ 'srcdir': 'C:/M/B/src/Python-3.12.9',
+ 'srcdir_b2h': 'C:/M/B/src/Python-3.12.9'}
 
 
 keys_to_replace = [
